@@ -91,6 +91,11 @@ void InputManager::backspace()
         m_expression.chop(m_stack.back());
         Q_EMIT expressionChanged();
 
+        if (m_expression.length() == 0) {
+            clear();
+            return;
+        }
+
         // Call the corresponding parser based on the type of expression.
         MathEngine * engineInstance = MathEngine::inst();
         if (m_isBinaryMode) {
@@ -98,7 +103,7 @@ void InputManager::backspace()
         } else {
             engineInstance->parse(m_expression);
         }
-        
+
         if(!MathEngine::inst()->error())
         {
             KNumber result = MathEngine::inst()->result();
