@@ -4,10 +4,11 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 #include <QApplication>
+#include <QCommandLineOption>
+#include <QCommandLineParser>
+#include <QIcon>
 #include <QObject>
 #include <QQmlApplicationEngine>
-#include <QCommandLineParser>
-#include <QCommandLineOption>
 #include <QQmlContext>
 #include <QQuickStyle>
 
@@ -50,9 +51,10 @@ int main(int argc, char *argv[])
     KAboutData aboutData(QStringLiteral("kalk"), 
                          i18n("Calculator"), 
                          QStringLiteral(KALK_VERSION_STRING), 
-                         i18n("Calculator in Kirigami"), 
+                         i18n("Calculator for Plasma"), 
                          KAboutLicense::GPL, 
-                         i18n("© 2020-2021 KDE Community"));
+                         i18n("© 2020-2022 KDE Community"));
+    aboutData.setBugAddress("https://bugs.kde.org/describecomponents.cgi?product=kalk");
     KAboutData::setApplicationData(aboutData);
 
     parser.process(app);
@@ -67,5 +69,8 @@ int main(int argc, char *argv[])
     // load main ui
     engine.load(QUrl(QStringLiteral("qrc:/qml/main.qml")));
 
+    // required for X11
+    app.setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.kalk")));
+
     return app.exec();
 }
